@@ -1,6 +1,6 @@
 /* BLINKENLIGHTS PROXY
- * version 0.95 date 2004-09-30
- * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
+ * version 0.96 date 2005-01-27
+ * Copyright (C) 2003-2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
 
@@ -403,11 +403,9 @@ int addr_str2range( char * p_str, st_addr_range * p_range, st_out_info * p_out_i
         return -EINVAL;
       }
     }
-    //check minimum and maximum port
-    if( port_min < 1 )
+    //check minimum port
+    if( port_min == 0 )
       port_min = 1;
-    if( port_max > 65535 )
-      port_max = 65535;
     if( port_min > port_max )
     {
       port_tmp = port_min;
@@ -499,11 +497,9 @@ int addr_str2range( char * p_str, st_addr_range * p_range, st_out_info * p_out_i
         return -EINVAL;
       }
     }
-    //check minimum and maximum port
+    //check minimum port
     if( port_min < 1 )
       port_min = 1;
-    if( port_max > 65535 )
-      port_max = 65535;
     if( port_min > port_max )
     {
       port_tmp = port_min;
