@@ -1,10 +1,10 @@
 /* BLINKENLIGHTS PROXY
- * version 0.95 date 2004-09-30
- * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
+ * version 0.96 date 2005-01-27
+ * Copyright (C) 2003-2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
 
-#include <malloc.h>
+#include <stdlib.h>
 #include <errno.h>
 
 #include "olist.h"
